@@ -192,6 +192,26 @@ class NumberType(BaseType):
         return float(value)
 
 
+class YearType(NumberType):
+    default_value = timezone.now().year
+    lookups = {
+        "equals": "year",
+        "not_equals": "year",
+        "gt": "year",
+        "gte": "year",
+        "lt": "year",
+        "lte": "year",
+        "is_null": "boolean",
+    }
+
+    @staticmethod
+    def _parse(value):
+        res = int(value)
+        if res <= 1:
+            raise Exception("Years must be > 1")
+        return res
+
+
 class DateTimeType(BaseType):
     default_value = "now"
     lookups = {
@@ -314,7 +334,18 @@ class BooleanType(BaseType):
             raise ValueError("Expected 'true' or 'false'")
 
 
-TYPES = {field_type.name: field_type for field_type in BaseType.__subclasses__()}
+def all_subclasses(cls):
+    res = set()
+    queue = {cls}
+    while queue:
+        cls = queue.pop()
+        subs = set(cls.__subclasses__())
+        queue.update(subs - res)
+        res.update(subs)
+    return res
+
+
+TYPES = {cls.name: cls for cls in all_subclasses(BaseType)}
 
 
 class BoundFieldMixin:
@@ -364,6 +395,13 @@ class BoundField(BoundFieldMixin):
             query_field.priority if orm_bound_field.concrete else None,
         )
 
+    def unsorted(self):
+        return self.__class__(self.orm_bound_field, self.pivoted, None, None)
+
+
+def _orm_fields(fields):
+    return [f.orm_bound_field for f in fields]
+
 
 class BoundQuery:
     def __init__(self, model_name, fields, filters):
@@ -410,36 +448,42 @@ class BoundQuery:
     def valid_filters(self):
         return [f for f in self.filters if f.is_valid]
 
-    @property
-    def bound_fields(self):
-        return [f.orm_bound_field for f in self.fields]
-
-    @property
-    def bound_filters(self):
-        return [f.orm_bound_field for f in self.valid_filters]
-
     @property
     def col_fields(self):
-        return [field.orm_bound_field for field in self.fields if field.pivoted]
+        return [f for f in self.fields if f.pivoted]
 
     @property
     def row_fields(self):
         if self.col_fields:
             return [
-                field.orm_bound_field
-                for field in self.fields
-                if field.orm_bound_field.can_pivot and not field.pivoted
+                f for f in self.fields if f.orm_bound_field.can_pivot and not f.pivoted
             ]
         else:
-            return [field.orm_bound_field for field in self.fields]
+            return self.fields
 
     @property
     def data_fields(self):
         if self.col_fields:
-            return [
-                field.orm_bound_field
-                for field in self.fields
-                if not field.orm_bound_field.can_pivot
-            ]
+            return [f for f in self.fields if not f.orm_bound_field.can_pivot]
         else:
             return []
+
+    @property
+    def bound_fields(self):
+        return _orm_fields(self.fields)
+
+    @property
+    def bound_filters(self):
+        return _orm_fields(self.valid_filters)
+
+    @property
+    def bound_col_fields(self):
+        return _orm_fields(self.col_fields)
+
+    @property
+    def bound_row_fields(self):
+        return _orm_fields(self.row_fields)
+
+    @property
+    def bound_data_fields(self):
+        return _orm_fields(self.data_fields)
