@@ -317,7 +317,7 @@ snapshots["test_query_html context"] = {
                         "concrete": True,
                         "model": None,
                         "prettyName": "year",
-                        "type": "number",
+                        "type": "year",
                     },
                 },
                 "sortedFields": [
@@ -399,7 +399,7 @@ snapshots["test_query_html context"] = {
                         "concrete": True,
                         "model": None,
                         "prettyName": "year",
-                        "type": "number",
+                        "type": "year",
                     },
                 },
                 "sortedFields": [
@@ -817,6 +817,7 @@ snapshots["test_query_html context"] = {
                 "sortedFields": ["id", "admin", "name"],
             },
             "weekday": {"fields": {}, "sortedFields": []},
+            "year": {"fields": {}, "sortedFields": []},
         },
         "baseUrl": "/data_browser/",
         "savedViews": [],
@@ -964,6 +965,28 @@ snapshots["test_query_html context"] = {
                 },
                 "sortedLookups": ["equals", "not_equals"],
             },
+            "year": {
+                "defaultLookup": "equals",
+                "defaultValue": 2020,
+                "lookups": {
+                    "equals": {"type": "year"},
+                    "gt": {"type": "year"},
+                    "gte": {"type": "year"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "year"},
+                    "lte": {"type": "year"},
+                    "not_equals": {"type": "year"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
         },
         "version": "redacted",
     },
@@ -1085,7 +1108,7 @@ snapshots["test_query_html_no_perms context"] = {
                         "concrete": True,
                         "model": None,
                         "prettyName": "year",
-                        "type": "number",
+                        "type": "year",
                     },
                 },
                 "sortedFields": [
@@ -1167,7 +1190,7 @@ snapshots["test_query_html_no_perms context"] = {
                         "concrete": True,
                         "model": None,
                         "prettyName": "year",
-                        "type": "number",
+                        "type": "year",
                     },
                 },
                 "sortedFields": [
@@ -1260,6 +1283,7 @@ snapshots["test_query_html_no_perms context"] = {
                 "sortedFields": ["count"],
             },
             "weekday": {"fields": {}, "sortedFields": []},
+            "year": {"fields": {}, "sortedFields": []},
         },
         "baseUrl": "/data_browser/",
         "savedViews": [],
@@ -1395,6 +1419,28 @@ snapshots["test_query_html_no_perms context"] = {
                 },
                 "sortedLookups": ["equals", "not_equals"],
             },
+            "year": {
+                "defaultLookup": "equals",
+                "defaultValue": 2020,
+                "lookups": {
+                    "equals": {"type": "year"},
+                    "gt": {"type": "year"},
+                    "gte": {"type": "year"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "year"},
+                    "lte": {"type": "year"},
+                    "not_equals": {"type": "year"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
         },
         "version": "redacted",
     },
@@ -1722,7 +1768,7 @@ snapshots["test_query_ctx context"] = {
                         "concrete": True,
                         "model": None,
                         "prettyName": "year",
-                        "type": "number",
+                        "type": "year",
                     },
                 },
                 "sortedFields": [
@@ -1804,7 +1850,7 @@ snapshots["test_query_ctx context"] = {
                         "concrete": True,
                         "model": None,
                         "prettyName": "year",
-                        "type": "number",
+                        "type": "year",
                     },
                 },
                 "sortedFields": [
@@ -2222,6 +2268,7 @@ snapshots["test_query_ctx context"] = {
                 "sortedFields": ["id", "admin", "name"],
             },
             "weekday": {"fields": {}, "sortedFields": []},
+            "year": {"fields": {}, "sortedFields": []},
         },
         "baseUrl": "/data_browser/",
         "savedViews": [],
@@ -2369,6 +2416,28 @@ snapshots["test_query_ctx context"] = {
                 },
                 "sortedLookups": ["equals", "not_equals"],
             },
+            "year": {
+                "defaultLookup": "equals",
+                "defaultValue": 2020,
+                "lookups": {
+                    "equals": {"type": "year"},
+                    "gt": {"type": "year"},
+                    "gte": {"type": "year"},
+                    "is_null": {"type": "boolean"},
+                    "lt": {"type": "year"},
+                    "lte": {"type": "year"},
+                    "not_equals": {"type": "year"},
+                },
+                "sortedLookups": [
+                    "equals",
+                    "not_equals",
+                    "gt",
+                    "gte",
+                    "lt",
+                    "lte",
+                    "is_null",
+                ],
+            },
         },
         "version": "redacted",
     },
